@@ -18,11 +18,11 @@
 // |          Lorenzo Alberton <l dot alberton at quipo dot it>           |
 // +----------------------------------------------------------------------+
 //
-// $Id$
+// $Id: Wrapper.php 2283 2009-09-04 14:46:22Z fishbone $
 //
 /**
  * @package Calendar
- * @version $Id$
+ * @version $Id: Wrapper.php 2283 2009-09-04 14:46:22Z fishbone $
  */
 
 /**
@@ -65,7 +65,7 @@ class Calendar_Decorator_Wrapper extends Calendar_Decorator
     {
         $Calendar = parent::fetch();
         if ($Calendar) {
-            $ret =& new $decorator($Calendar);
+            $ret = new $decorator($Calendar);
         } else {
             $ret = false;
         }
@@ -82,7 +82,7 @@ class Calendar_Decorator_Wrapper extends Calendar_Decorator
     {
         $children = parent::fetchAll();
         foreach ($children as $key => $Calendar) {
-            $children[$key] = & new $decorator($Calendar);
+            $children[$key] = new $decorator($Calendar);
         }
         return $children;
     }
