@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: textConvManager.php 3828 2010-11-16 06:20:21Z fishbone $
+ * @version    SVN: $Id: textConvManager.php 3946 2011-01-20 05:08:19Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/htmlEdit.php');
@@ -712,5 +712,38 @@ class TextConvManager extends Core
 		
 		return $ret;
 	}
+	/**
+	 * ウィジェット埋め込みタグを変換
+	 *
+	 * @param string $src		変換するデータ
+	 * @param string $dest      変換後データ
+	 * @return bool				true=成功、false=失敗
+	 */
+	function convWidgetTag($src, &$dest)
+	{
+		$startTag = str_replace('[', '\[', M3_TAG_START . M3_TAG_MACRO_WIDGET);		// 「[」を正規表現用に「\[」に変換
+		$endTag = str_replace(']', '\]', M3_TAG_END);		// 「]」を正規表現用に「\]」に変換
+		$str = '/' . $startTag . ':(.*?)' . M3_WIDGET_ID_SEPARATOR . '(\d+?)' . $endTag . '/';
+        $dest = preg_replace_callback($str, array($this, '_replace_widget_tag_callback'), $src);
+		return true;
+	}
+	/**
+	 * ウィジェット埋め込みタグ変換コールバック関数
+	 *
+	 * @param array $matchData		検索マッチデータ
+	 * @return string				変換後データ
+	 */
+    function _replace_widget_tag_callback($matchData)
+	{
+		global $gPageManager;
+		
+		$widgetId = $matchData[1];			// ウィジェットID
+		$configId = intval($matchData[2]);		// 定義ID
+
+		// ウィジェットID、ウィジェット定義IDからウィジェット出力を取得
+		$widgetOutput = $gPageManager->getWidgetOutput($widgetId, $configId);
+		
+		return $widgetOutput;
+    }
 }
 ?>
