@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_base.sql 3942 2011-01-19 10:29:05Z fishbone $
+-- * @version    SVN: $Id: insert_base.sql 3977 2011-02-04 03:06:11Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -152,10 +152,11 @@ INSERT INTO _page_id
 ('bbs',          1,       '',                '',            '掲示板',                           '掲示板画面用',                       4,           0,              true,      false,     true),
 ('blog',         1,       '',                '',            'ブログ',                           'ブログ画面用',                       5,           0,              true,      false,     true),
 ('wiki',         1,       '',                '',            'Wiki',                             'Wiki画面用',                         6,           0,              true,      false,     true),
-('photo',        1,       '',                '',            'フォトアルバム',                   'フォトアルバム画面用',               7,           0,              true,      false,     true),
-('contact',      1,       '',                '',            'お問い合わせ',                     'お問い合わせ画面用',                 8,           0,              true,      false,     true),
-('contact2',     1,       '',                '',            'お問い合わせ2',                    'お問い合わせ画面用',                 9,           0,              true,      false,     true),
-('contact3',     1,       '',                '',            'お問い合わせ3',                    'お問い合わせ画面用',                 10,          0,              true,      false,     true),
+('event',        1,       '',                '',            'イベント',                         'イベント画面用',                     7,           0,              true,      false,     true),
+('photo',        1,       '',                '',            'フォトアルバム',                   'フォトアルバム画面用',               8,           0,              true,      false,     true),
+('contact',      1,       '',                '',            'お問い合わせ',                     'お問い合わせ画面用',                 9,           0,              true,      false,     true),
+('contact2',     1,       '',                '',            'お問い合わせ2',                    'お問い合わせ画面用',                 10,          0,              true,      false,     true),
+('contact3',     1,       '',                '',            'お問い合わせ3',                    'お問い合わせ画面用',                 11,          0,              true,      false,     true),
 ('reserve',      1,       '',                '',            '予約',                             '予約画面用',                         20,          0,              true,      false,     true),
 ('search',       1,       '',                '',            '検索',                             '検索画面用',                         21,          0,              true,      false,     true),
 ('user',         1,       '',                '',            'ユーザコンテンツ',                 'ユーザ作成コンテンツ用',             50,          0,              true,      false,     true),
@@ -173,13 +174,18 @@ INSERT INTO _page_info
 ('index',     'blog',      'blog',          false),
 ('index',     'wiki',      'wiki',          false),
 ('index',     'user',      'user',          false),
+('index',     'event',     'event',         false),
 ('index',     'contact',   '',              true),
+('index',     'contact2',  '',              true),
+('index',     'contact3',  '',              true),
 ('index',     'safe',      '',              true),
 ('m_index',   'content',   'content',       false),
 ('m_index',   'shop',      'product',       false),
 ('m_index',   'bbs',       'bbs',           false),
 ('m_index',   'blog',      'blog',          false),
 ('m_index',   'wiki',      'wiki',          false),
+('m_index',   'user',      'user',          false),
+('m_index',   'event',     'event',         false),
 ('s_index',   'content',   'content',       false),
 ('connector', 'content',   'content',       false);
 
