@@ -7,9 +7,9 @@
 -- *
 -- * @package    Magic3 Framework
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
--- * @copyright  Copyright 2006-2010 Magic3 Project.
+-- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_std.sql 3964 2011-01-26 07:40:04Z fishbone $
+-- * @version    SVN: $Id: insert_std.sql 3997 2011-02-15 01:30:51Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -21,17 +21,17 @@
 DELETE FROM _nav_item WHERE ni_id >= 500 AND ni_id < 1000;
 DELETE FROM _nav_item WHERE ni_id >= 10500 AND ni_id < 11000;
 INSERT INTO _nav_item
-(ni_id, ni_parent_id, ni_index, ni_nav_id,    ni_task_id,                      ni_view_control, ni_param, ni_name,    ni_help_title, ni_help_body) VALUES
-(500,   0,            4,        'admin_menu', '_widget',                       0,               '',       'ウィジェット設定', 'ウィジェット設定', '個別のウィジェットの設定を行います。'),
-(501,   500,          0,        'admin_menu', 'configwidget_default_content',  0,               '',       '汎用コンテンツメイン', 'デフォルトコンテンツ', 'Webサイトのコンテンツを管理する設定画面です。'),
-(502,   500,          1,        'admin_menu', 'configwidget_ec_main',          0,               '',       'Eコマースメイン', 'Eコマースメイン', 'Eコマース機能のメインの管理画面です。'),
-(503,   500,          2,        'admin_menu', 'configwidget_blog_main',        0,               '',       'ブログメイン', 'ブログメイン', 'ブログ機能のメインの管理画面です。'),
-(504,   500,          3,        'admin_menu', 'configwidget_wiki_main',        0,               '',       'Wikiメイン', 'Wikiメイン', 'Wiki機能のメインの管理画面です。'),
-(10500,   0,            4,        'admin_menu.en', '_widget',                       0,               '',       'Widget Administration', 'Widget Administration', 'Administrate widgets with widget config window.'),
-(10501,   10500,          0,        'admin_menu.en', 'configwidget_default_content',  0,               '',       'Main For Standard Contents', 'Main For Standard Contents', 'Main function to administrate standard contents.'),
-(10502,   10500,          1,        'admin_menu.en', 'configwidget_ec_main',          0,               '',       'Main For E-Commerce', 'Main For E-Commerce', 'Main function to administrate E-Commerce.'),
-(10503,   10500,          2,        'admin_menu.en', 'configwidget_blog_main',        0,               '',       'Main For Blog', 'Main For Blog', 'Main function to administrate Blog.'),
-(10504,   10500,          3,        'admin_menu.en', 'configwidget_wiki_main',        0,               '',       'Main For Wiki', 'Main For Wiki', 'Main function to administrate Wiki.');
+(ni_id, ni_parent_id, ni_index, ni_nav_id,    ni_task_id,                     ni_group_id, ni_view_control, ni_param, ni_name,    ni_help_title, ni_help_body, ni_visible) VALUES
+(500,   0,            4,        'admin_menu', '_content',                      '',          0,               '',       'コンテンツ管理', 'コンテンツ管理', '各種コンテンツを管理します。', true),
+(501,   500,          0,        'admin_menu', 'configwidget_default_content', '',          0,               '',       '汎用コンテンツ', '汎用コンテンツ', '汎用コンテンツを管理します。(コンテンツメインウィジェット)', true),
+(502,   500,          1,        'admin_menu', 'configwidget_blog_main',       '',          0,               '',       'ブログ', 'ブログ', 'ブログコンテンツを管理します。(バナーメインウィジェット)', true),
+(503,   500,          2,        'admin_menu', 'configwidget_event_main',       '',          0,               '',       'イベント情報', 'イベント情報', 'イベント情報を管理します。(イベント情報メインウィジェット)', true),
+(504,   500,          3,        'admin_menu', 'configwidget_banner3',        '',          0,               '',       'バナー', 'バナー', 'バナーを管理します。(バナーメインウィジェット)', true),
+(10500,   0,            4,        'admin_menu.en', '_content',                      '',          0,               '',       'Configure Contents', 'Configure Contents', 'Administrate various contents.', true),
+(10501,   10500,          0,        'admin_menu.en', 'configwidget_default_content', '',          0,               '',       'Standard Contents', 'Standard Contents', 'Administrate standard contents.', true),
+(10502,   10500,          1,        'admin_menu.en', 'configwidget_blog_main',       '',          0,               '',       'Blog Contents', 'Blog Contents', 'Administrate blog contents.', true),
+(10503,   10500,          2,        'admin_menu.en', 'configwidget_event_main',       '',          0,               '',       'Event Information', 'Event Information', 'Administrate event Information.', true),
+(10504,   10500,          3,        'admin_menu.en', 'configwidget_banner3',        '',          0,               '',       'Banner', 'Banner', 'Administrate banners.', true);
 
 -- Wiki設定マスター
 INSERT INTO wiki_config (wg_id,        wg_value,     wg_name,                 wg_index)
