@@ -10,13 +10,13 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installCheckenvWidgetContainer.php 3309 2010-06-29 07:47:42Z fishbone $
+ * @version    SVN: $Id: _installCheckenvWidgetContainer.php 3791 2010-11-08 07:07:17Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/_installBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/_installDb.php');
 
-class _installCheckenvWidgetContainer extends BaseWidgetContainer
+class _installCheckenvWidgetContainer extends _installBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 
@@ -56,40 +56,38 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		
 		// 利用可能なDBをチェック
 		// PostgreSQLのPDOが使用可能かどうか
 		if (extension_loaded('pdo_pgsql')){
-			$status = '利用可能';
+			$status = $this->_('available');
 			$version = exec("psql --version", $output);	// PostgreSQLバージョン取得
 			// 出力からバージョンを抜き出す
 			$words = explode(' ', $output[0]);
 			$version = $words[count($words)-1];		// 行末にはバージョン数値が存在する
-			if (empty($version)) $version = 'バージョン不明';
+			if (empty($version)) $version = $this->_('version unknown');// バージョン不明
 			$status .= '(' . $version . ')';
 			$data = '<b><font color="green">' . $status . '</font></b>';
 		} else {
-			$status = '利用不可(pdo_pgsqlがインストールされていません)';
+			$status = $this->_('not available(pdo_pgsql not installed)');		// 利用不可(pdo_pgsqlがインストールされていません)
 			$data = '<b><font color="red">' . $status . '</font></b>';
 		}
 		$this->tmpl->addVar("_widget","current_postgresql_status", $data);
 
 		// MySQLのPDOが使用可能かどうか
 		if (extension_loaded('pdo_mysql')){
-			$status = '利用可能';
+			$status = $this->_('available');
 			$version = exec("mysql_config --version");	// MySQLバージョン取得
-			if (empty($version)) $version = 'バージョン不明';
+			if (empty($version)) $version = $this->_('version unknown');
 			$status .= '(' . $version . ')';
 			$data = '<b><font color="green">' . $status . '</font></b>';
 		} else {
-			$status = '利用不可(pdo_mysqlがインストールされていません)';
+			$status = $this->_('not available(pdo_mysql not installed)');			// 利用不可(pdo_mysqlがインストールされていません)
 			$data = '<b><font color="red">' . $status . '</font></b>';
 		}
 		$this->tmpl->addVar("_widget","current_mysql_status", $data);
 		
 		// PHPのバージョンをチェック
-		$data = '<b><font color="green">5.1.0 以上</font></b>';
+		$data = '<b><font color="green">' . $this->_('5.1.0 more') . '</font></b>';		// 5.1.0 以上
 		$this->tmpl->addVar("_widget","config_php_version", $data);
 		
 		$phpVer = phpversion();
@@ -101,7 +99,7 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget","current_php_version", $data);
 		
 		// メモリ使用量のチェック
-		$data = '<b><font color="green">' . M3_SYSTEM_MIN_MEMORY . 'バイト以上を奨励</font></b>';
+		$data = '<b><font color="green">' . M3_SYSTEM_MIN_MEMORY . $this->_('bytes(encouraged)') . '</font></b>';
 		$this->tmpl->addVar("_widget","config_memory_limit", $data);
 		
 		$limit = ini_get('memory_limit');
@@ -113,8 +111,8 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget","current_memory_limit", $data);
 		
 		// セーフモード
-		$data = '<b><font color="green">offを奨励</font></b>';
-		//$data = '<br>';
+		$data = '<b><font color="green">' . $this->_('off(encouraged)') . '</font></b>';
+		//$data = '<br />';
 		$this->tmpl->addVar("_widget","config_safe_mode", $data);
 		if (ini_get('safe_mode')){
 			//$data = '<b><font color="red">on</font></b>';
@@ -158,7 +156,7 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		if (extension_loaded('pdo')){
 			$data = '<b><font color="green">on</font></b>';
 		} else {
-			$data = '<b><font color="red">off(pdoがインストールされていません)</font></b>';
+			$data = '<b><font color="red">off(' . $this->_('PDO not installed') . ')</font></b>';		// pdoがインストールされていません
 		}
 		$this->tmpl->addVar("_widget","current_pdo", $data);
 		
@@ -209,7 +207,8 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		}
 		$this->tmpl->addVar("_widget","current_dom", $data);
 		// xml
-		$data = '<b><font color="green">offでも動作可</font></b>';
+		//$data = '<b><font color="green">offでも動作可</font></b>';
+		$data = '';
 		$this->tmpl->addVar("_widget","config_xml", $data);
 		if (extension_loaded('xml')){
 			$data = '<b><font color="green">on</font></b>';
@@ -218,31 +217,31 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		}
 		$this->tmpl->addVar("_widget","current_xml", $data);
 		// gettext
-		$data = '<b><font color="green">on</font></b>';
+/*		$data = '<b><font color="green">on</font></b>';
 		$this->tmpl->addVar("_widget","config_gettext", $data);
 		if (extension_loaded('gettext')){
 			$data = '<b><font color="green">on</font></b>';
 		} else {
 			$data = '<b><font color="red">off</font></b>';
 		}
-		$this->tmpl->addVar("_widget","current_gettext", $data);
+		$this->tmpl->addVar("_widget","current_gettext", $data);*/
 		
 		// 設定ファイルのパス
 		$data = $this->gConfig->configFilePath();
 		$this->tmpl->addVar("_widget","current_config_path", $data);
 		
 		// 設定ファイルが書き込み可能かどうかチェック
-		$data = '<b><font color="green">書き込み可能</font></b>';
+		$data = '<b><font color="green">' . $this->_('writable') . '</font></b>';
 		$this->tmpl->addVar("_widget","config_access", $data);
 		
 		if ($this->gConfig->isConfigDirWritable()){
 			if ($this->gConfig->isConfigFileWritable()){
-				$data = '<b><font color="green">書き込み可能</font></b>';
+				$data = '<b><font color="green">' . $this->_('writable') . '</font></b>';
 			} else {
-				$data = '<b><font color="red">書き込み不可</font></b>';
+				$data = '<b><font color="red">' . $this->_('not writable') . '</font></b>';
 			}
 		} else {
-			$data = '<b><font color="red">ディレクトリ書き込み不可</font></b>';
+			$data = '<b><font color="red">' . $this->_('directory not writable') . '</font></b>';			// ディレクトリ書き込み不可
 		}
 		$this->tmpl->addVar("_widget","current_access", $data);
 		
@@ -282,22 +281,22 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget","current_session_path", $sp);
 						
 		//$data = '<b><font color="green">どちらでも可</font></b>';
-		$data = '<br>';
+		$data = '<br />';
 		$this->tmpl->addVar("_widget","config_session_access", $data);
 		
 		if (@is_writable($sp)){
-			$data = '<b><font color="green">書き込み可能</font></b>';
+			$data = '<b><font color="green">' . $this->_('writable') . '</font></b>';
 		} else {
-			$data = '<b><font color="green">書き込み不可</font></b>';
+			$data = '<b><font color="green">' . $this->_('not writable') . '</font></b>';
 		}
 		$this->tmpl->addVar("_widget","current_session_access", $data);
 		
 		// セッションID
-		$data = '<b><font color="green">取得可</font></b>';
+		$data = '<b><font color="green">' . $this->_('enable') . '</font></b>';
 		$this->tmpl->addVar("_widget","config_session_id", $data);
 		$sid = session_id();
 		if (empty($sid)){
-			$data = '<b><font color="red">取得不可</font></b>';
+			$data = '<b><font color="red">' . $this->_('disable') . '</font></b>';
 		} else {
 			$data = '<b><font color="green">' . $sid . '</font></b>';
 		}
@@ -308,29 +307,50 @@ class _installCheckenvWidgetContainer extends BaseWidgetContainer
 		$path = $this->gEnv->getWorkDirPath();
 		$this->tmpl->addVar("_widget","current_tmp_dir", $path);
 		
-		$data = '<b><font color="green">書き込み可能</font></b>';
+		$data = '<b><font color="green">' . $this->_('writable') . '</font></b>';
 		$this->tmpl->addVar("_widget","config_tmp_dir_access", $data);
 		
 		if (is_writable($path)){
-			$data = '<b><font color="green">書き込み可能</font></b>';
+			$data = '<b><font color="green">' . $this->_('writable') . '</font></b>';
 		} else {
-			$data = '<b><font color="red">書き込み不可</font></b>';
+			$data = '<b><font color="red">' . $this->_('not writable') . '</font></b>';
 		}
 		$this->tmpl->addVar("_widget","current_tmp_dir_access", $data);
 		
 		// 画像格納ディレクトリパス
-		$path = $gEnvManager->getResourcePath();
+		$path = $this->gEnv->getResourcePath();
 		$this->tmpl->addVar("_widget","current_resource_dir", $path);
 						
-		$data = '<b><font color="green">書き込み可能</font></b>';
+		$data = '<b><font color="green">' . $this->_('writable') . '</font></b>';
 		$this->tmpl->addVar("_widget","config_resource_dir_access", $data);
 		
 		if (is_writable($path)){
-			$data = '<b><font color="green">書き込み可能</font></b>';
+			$data = '<b><font color="green">' . $this->_('writable') . '</font></b>';
 		} else {
-			$data = '<b><font color="red">書き込み不可</font></b>';
+			$data = '<b><font color="red">' . $this->_('not writable') . '</font></b>';
 		}
 		$this->tmpl->addVar("_widget","current_resource_dir_access", $data);
+		
+		// テキストをローカライズ
+		$localeText = array();
+		$localeText['title_check_env'] = $this->_('Check Install Environment');
+		$localeText['label_check_item'] = $this->_('Check Item');
+		$localeText['label_required_value'] = $this->_('Required Value');
+		$localeText['label_current_value'] = $this->_('Current Value');
+		$localeText['label_php_version'] = $this->_('PHP Version');
+		$localeText['label_memory_limit'] = $this->_('Memory Limit(bytes)');			// 最大メモリ量(バイト)
+		$localeText['label_permit_upload'] = $this->_('Permit file uploading');			// ファイルアップロード許可
+		$localeText['label_session_path'] = $this->_('Session Path');	// セッション保存パス
+		$localeText['label_session_path_permission'] = $this->_('Session Path Permission');// セッション保存パスのアクセス権
+		$localeText['label_session_id'] = $this->_('Session ID');// セッションID
+		$localeText['label_tmp_dir'] = $this->_('Temporary Directory(Install Use)');// 一時ディレクトリ(インストール時に使用する一時ディレクトリ)
+		$localeText['label_tmp_dir_permission'] = $this->_('Temporary Directory Permission');// 一時ディレクトリのアクセス権
+		$localeText['label_msg_dir_permission'] = $this->_('If directory is not writable, change permission to write or chenge directory to be writable.');// 書き込み不可の場合は書き込み可能なディレクトリあるいはアクセス権に設定する必要あり
+		$localeText['label_magic3_config_file'] = $this->_('Magic3 Config File');		 // Magic3設定ファイルのパス
+		$localeText['label_magic3_config_file_permission'] = $this->_('Magic3 Config File Permission');// Magic3設定ファイルのアクセス権
+		$localeText['label_resource_dir'] = $this->_('Resource Directory(for Image files etc)');// リソース(画像等)格納ディレクトリ
+		$localeText['label_resource_dir_permission'] = $this->_('Resource Directory Permission');// リソース(画像等)格納ディレクトリのアクセス権
+		$this->setLocaleText($localeText);
 	}
 }
 ?>
