@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 3883 2010-12-07 10:14:56Z fishbone $
+ * @version    SVN: $Id: index.php 3894 2010-12-16 02:06:58Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -75,14 +75,6 @@ $HELP['edittable_del_btn']['body'] = '選択されているレコードを削除
 $HELP['edittable_ret_btn']['title'] = '戻るボタン';
 $HELP['edittable_ret_btn']['body'] = 'レコード一覧へ戻ります。';
 
-// ########## 管理メニュー編集編集 ##########
-$HELP['editmenu_config_others_btn']['title'] = 'その他ボタン';
-$HELP['editmenu_config_others_btn']['body'] = 'その他の設定を行います。';
-$HELP['editmenu_ret_btn']['title'] = '戻るボタン';
-$HELP['editmenu_ret_btn']['body'] = '管理メニュー編集へ戻ります。';
-$HELP['editmenu_top_image']['title'] = '管理メニュー画像';
-$HELP['editmenu_top_image']['body'] = '管理メニュー上に表示する画像です。[Magic3ルート]からの相対パスで指定します。';
-
 // ########## 置換文字列 ##########
 $HELP['usercustom_list']['title'] = '置換文字列一覧';
 $HELP['usercustom_list']['body'] = '置換文字列一覧です。置換文字列は、コンテンツテキストに埋め込み、コンテンツ表示時に自動変換される文字列です。';
@@ -346,32 +338,6 @@ $HELP['adjustwidget_margin']['body'] = 'ウィジェットの表示内容のマ
 $HELP['adjustwidget_render']['title'] = '描画処理';
 $HELP['adjustwidget_render']['body'] = '「Joomla!スタイルの描画処理」をオンにするとウィジェットの周囲の枠やタイトルが付加されます。チェックをはずした場合はウィジェットのプレーンな出力が表示されます。';
 
-// ########## リソースブラウズ ##########
-$HELP['resbrowse']['title'] = 'リソースブラウズ';
-$HELP['resbrowse']['body'] = 'サムネール画像を見ながら画像ファイルの処理が行えます。';
-
-// ########## ファイルブラウズ ##########
-$HELP['filebrowse']['title'] = 'ファイルアップロード';
-$HELP['filebrowse']['body'] = '複数のファイルを一度にアップロードできます。';
-$HELP['filebrowse_path']['title'] = 'パス';
-$HELP['filebrowse_path']['body'] = '現在のディレクトリパスを示します。';
-$HELP['filebrowse_filename']['title'] = 'ファイル名';
-$HELP['filebrowse_filename']['body'] = 'ファイル名、ディレクトリ名を示します。';
-$HELP['filebrowse_size']['title'] = 'サイズ';
-$HELP['filebrowse_size']['body'] = 'ファイルのサイズを示します。';
-$HELP['filebrowse_permission']['title'] = 'パーミッション';
-$HELP['filebrowse_permission']['body'] = 'ファイル、ディレクトリのパーミッションを示します。';
-$HELP['filebrowse_owner']['title'] = '所有者';
-$HELP['filebrowse_owner']['body'] = 'ファイル、ディレクトリの所有者を示します。';
-$HELP['filebrowse_group']['title'] = 'グループ';
-$HELP['filebrowse_group']['body'] = 'ファイル、ディレクトリのグループ所有者を示します。';
-$HELP['filebrowse_date']['title'] = '更新日時';
-$HELP['filebrowse_date']['body'] = 'ファイル、ディレクトリの更新日時を示します。';
-$HELP['filebrowse_upload_status']['title'] = 'ファイルアップロード状況';
-$HELP['filebrowse_upload_status']['body'] = 'ファイルのアップロードはここから行います。ファイルアップロード時はアップロード状況が表示されます。';
-$HELP['filebrowse_del_btn']['title'] = '削除ボタン';
-$HELP['filebrowse_del_btn']['body'] = '選択されているメニュー項目を削除します。<br />メニュー項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。<br />「resource」ディレクトリ以下のファイルのみ削除可能です。';
-
 // ########## テナントサーバ管理 ##########
 $HELP['tenantserver']['title'] = 'テナントサーバ管理';
 $HELP['tenantserver']['body'] = 'テナントサーバの管理を行います';
