@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_bbs_2ch_mainBaseWidgetContainer.php 3274 2010-06-22 06:22:06Z fishbone $
+ * @version    SVN: $Id: admin_bbs_2ch_mainBaseWidgetContainer.php 3559 2010-09-01 08:03:26Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -22,12 +22,14 @@ class admin_bbs_2ch_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 	protected $_boardId;	// 掲示板ID
 	const DEFAULT_BBS_ID = 'board1';		// デフォルトの掲示板ID
 	const DEFAULT_TOP_PAGE = 'message';		// デフォルトのトップページ
+	const DEFAULT_BOTTOM_MESSAGE = '<center><b>どのような形の削除依頼であれ公開させていただきます。</b></center>';		// デフォルトのトップ画面下部メッセージ
 	const WIDGET_TITLE_NAME = '2ちゃんねる風BBSメイン';				// ウィジェットタイトル名
 	const CF_BBS_TITLE = 'title';			// 掲示板タイトル
 	const CF_TITLE_COLOR = 'title_color';	// タイトルカラー
 	const CF_TOP_LINK = 'top_link';		// トップ画像のリンク先
 	const CF_TOP_IMAGE = 'top_image';		// トップ画像
 	const CF_BBS_GUIDE = 'bbs_guide';		// 掲示板規則
+	const CF_BOTTOM_MESSAGE = 'bottom_message';		// トップ画面下部メッセージ
 	const CF_BG_IMAGE = 'bg_image';		// 背景画像
 	const CF_BG_COLOR = 'bg_color';		// 背景色
 	const CF_TEXT_COLOR = 'text_color';		// 文字色
