@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_custom_searchWidgetContainer.php 3058 2010-04-23 05:41:13Z fishbone $
+ * @version    SVN: $Id: admin_custom_searchWidgetContainer.php 3525 2010-08-24 05:32:45Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -117,6 +117,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 		// 検索対象
 		$isTargetContent = ($request->trimValueOf('item_target_content') == 'on') ? 1 : 0;		// 汎用コンテンツを検索対象とするかどうか
 		$isTargetUser = ($request->trimValueOf('item_target_user') == 'on') ? 1 : 0;			// ユーザ作成コンテンツを検索対象とするかどうか
+		$isTargetBlog = ($request->trimValueOf('item_target_blog') == 'on') ? 1 : 0;			// ブログ記事を検索対象とするかどうか
 		
 		// カテゴリ項目定義
 		$fieldCount = intval($request->trimValueOf('fieldcount'));		// カテゴリ定義項目数
@@ -147,7 +148,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 		} else if ($act == 'add'){// 新規追加
 			// 入力チェック
 			$this->checkInput($name, '名前');
-			if (empty($isTargetContent) && empty($isTargetUser)) $this->setUserErrorMsg('検索対象が選択されていません');
+			if (empty($isTargetContent) && empty($isTargetUser) && empty($isTargetBlog)) $this->setUserErrorMsg('検索対象が選択されていません');
 			$this->checkNumeric($resultCount, '表示件数');
 			
 			// 設定名の重複チェック
@@ -171,6 +172,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 				$newObj->searchResetId = $this->searchResetId;		// 検索エリアリセットボタンのタグID
 				$newObj->isTargetContent = $isTargetContent;		// 汎用コンテンツを検索対象とするかどうか
 				$newObj->isTargetUser = $isTargetUser;			// ユーザ作成コンテンツを検索対象とするかどうか
+				$newObj->isTargetBlog = $isTargetBlog;			// ブログ記事を検索対象とするかどうか
 				$newObj->fieldInfo = $this->fieldInfoArray;			// カテゴリ定義
 				
 				$ret = $this->addPageDefParam($defSerial, $defConfigId, $this->paramObj, $newObj);
@@ -185,7 +187,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 			}
 		} else if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
-			if (empty($isTargetContent) && empty($isTargetUser)) $this->setUserErrorMsg('検索対象が選択されていません');
+			if (empty($isTargetContent) && empty($isTargetUser) && empty($isTargetBlog)) $this->setUserErrorMsg('検索対象が選択されていません');
 			$this->checkNumeric($resultCount, '表示件数');
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
@@ -200,6 +202,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 					$targetObj->searchResetId = $this->searchResetId;		// 検索エリアリセットボタンのタグID
 					$targetObj->isTargetContent = $isTargetContent;		// 汎用コンテンツを検索対象とするかどうか
 					$targetObj->isTargetUser = $isTargetUser;			// ユーザ作成コンテンツを検索対象とするかどうか
+					$targetObj->isTargetBlog = $isTargetBlog;			// ブログ記事を検索対象とするかどうか
 					$targetObj->fieldInfo = $this->fieldInfoArray;			// カテゴリ定義
 				}
 				
@@ -237,6 +240,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 				
 				$isTargetContent = 1;		// 汎用コンテンツを検索対象とするかどうか
 				$isTargetUser = 1;			// ユーザ作成コンテンツを検索対象とするかどうか
+				$isTargetBlog = 0;			// ブログ記事を検索対象とするかどうか
 			}
 			$this->serialNo = 0;
 		} else {		// 更新の場合
@@ -250,6 +254,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 					$this->searchResetId = $targetObj->searchResetId;		// 検索エリアリセットボタンのタグID
 					$isTargetContent = $targetObj->isTargetContent;		// 汎用コンテンツを検索対象とするかどうか
 					$isTargetUser = $targetObj->isTargetUser;			// ユーザ作成コンテンツを検索対象とするかどうか
+					$isTargetBlog = $targetObj->isTargetBlog;			// ブログ記事を検索対象とするかどうか
 					$searchTemplate = $targetObj->searchTemplate;		// 検索用テンプレート
 					if (!empty($targetObj->fieldInfo)) $this->fieldInfoArray = $targetObj->fieldInfo;			// 項目定義
 				}
@@ -298,6 +303,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 		$this->tmpl->addVar('_widget', 'tag_end', M3_TAG_END);		// 置換タグ(後)
 		if (!empty($isTargetContent)) $this->tmpl->addVar('_widget', 'target_content_checked', 'checked');		// 汎用コンテンツを検索対象とするかどうか
 		if (!empty($isTargetUser)) $this->tmpl->addVar('_widget', 'target_user_checked', 'checked');			// ユーザ作成コンテンツを検索対象とするかどうか
+		if (!empty($isTargetBlog)) $this->tmpl->addVar('_widget', 'target_blog_checked', 'checked');			// ブログ記事を検索対象とするかどうか
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);// 選択中のシリアル番号、IDを設定
 		
 		// ボタンの表示制御
