@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_m_contactusWidgetContainer.php 426 2008-03-24 02:50:30Z fishbone $
+ * @version    SVN: $Id: admin_m_contactusWidgetContainer.php 867 2008-07-28 09:04:54Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
@@ -58,6 +58,7 @@ class admin_m_contactusWidgetContainer extends BaseWidgetContainer
 	function _assign($request, &$param)
 	{
 		global $gEnvManager;
+		global $gPageManager;
 		
 		$defaultLang	= $gEnvManager->getDefaultLanguage();
 		$act = $request->trimValueOf('act');
@@ -80,7 +81,8 @@ class admin_m_contactusWidgetContainer extends BaseWidgetContainer
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 				} else {
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
-				}				
+				}
+				$gPageManager->updateParentWindow();// 親ウィンドウを更新
 			}
 		} else {		// 初期表示の場合
 			// デフォルト値の設定
