@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m_pc_contentWidgetContainer.php 2454 2009-10-23 04:58:25Z fishbone $
+ * @version    SVN: $Id: m_pc_contentWidgetContainer.php 3728 2010-10-24 09:16:35Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -24,6 +24,7 @@ class m_pc_contentWidgetContainer extends BaseWidgetContainer
 	private $currentDay;		// 現在日
 	private $currentHour;		// 現在時間
 	private $headTitle;		// HTMLヘッダタイトル
+	private $currentRootUrl;		// 現在のページのルートURL
 	const CONTENT_TYPE = 'ct';		// 参照数カウント用
 		
 	/**
@@ -37,15 +38,6 @@ class m_pc_contentWidgetContainer extends BaseWidgetContainer
 		// DBオブジェクト作成
 		$this->db = new pc_contentDb();
 	}
-	/**
-	 * ウィジェット単位のアクセス制御
-	 *
-	 * @param RequestManager $request		HTTPリクエスト処理クラス
-	 */
-	function _checkAccess($request)
-	{
-		return true;
-	}
 	/**
 	 * テンプレートファイルを設定
 	 *
@@ -71,37 +63,37 @@ class m_pc_contentWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-		
 		// 現在日時を取得
 		$this->currentDay = date("Y/m/d");		// 日
 		$this->currentHour = (int)date("H");		// 時間
 
+		// 現在のページのルートURL
+		$this->currentRootUrl = $this->gEnv->getRootUrlByCurrentPage();
+		
 		// ログインユーザでないときは、ユーザ制限のない項目だけ表示
 		$all = false;
-		if ($gEnvManager->isCurrentUserLogined()) $all = true;
+		if ($this->gEnv->isCurrentUserLogined()) $all = true;
 		
 		$contentid = $request->trimValueOf('contentid');
 		if (empty($contentid)){	// コンテンツIDがないときはデフォルトデータを取得
-			$this->db->getContentItems(array($this, 'itemsLoop'), null, $gEnvManager->getCurrentLanguage(), $all);
+			$this->db->getContentItems(array($this, 'itemsLoop'), null, $this->gEnv->getCurrentLanguage(), $all);
 			if (!$this->_contentCreated){		// コンテンツが取得できなかったときはデフォルト言語で取得
-				$this->db->getContentItems(array($this, 'itemsLoop'), null, $gEnvManager->getDefaultLanguage(), $all);
+				$this->db->getContentItems(array($this, 'itemsLoop'), null, $this->gEnv->getDefaultLanguage(), $all);
 			}
 		} else {
 			// データエラーチェック
 			$contentIdArray = explode(',', $contentid);
 			if (ValueCheck::isNumeric($contentIdArray)){		// すべて数値であるかチェック
-				$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $gEnvManager->getCurrentLanguage(), $all);
+				$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $this->gEnv->getCurrentLanguage(), $all);
 				if (!$this->_contentCreated){		// コンテンツが取得できなかったときはデフォルト言語で取得
-					$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $gEnvManager->getDefaultLanguage(), $all);
+					$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $this->gEnv->getDefaultLanguage(), $all);
 				}
 			} else {
 				$this->setAppErrorMsg('IDにエラー値があります');
 			}
 		}
 		// HTMLサブタイトルを設定
-		if (!empty($this->headTitle)) $gPageManager->setHeadSubTitle($this->headTitle);
+		if (!empty($this->headTitle)) $this->gPage->setHeadSubTitle($this->headTitle);
 	}
 	/**
 	 * 取得したコンテンツ項目をテンプレートに設定する
@@ -113,8 +105,6 @@ class m_pc_contentWidgetContainer extends BaseWidgetContainer
 	 */
 	function itemsLoop($index, $fetchedRow)
 	{
-		global $gEnvManager;
-			
 		// ビューカウントを更新
 		if (!$this->gEnv->isSystemManageUser()){		// システム運用者以上の場合はカウントしない
 			$this->gInstance->getAnalyzeManager()->updateContentViewCount(self::CONTENT_TYPE, $fetchedRow['cn_serial'], $this->currentDay, $this->currentHour);
@@ -126,13 +116,16 @@ class m_pc_contentWidgetContainer extends BaseWidgetContainer
 		
 		// HTMLを出力
 		// 出力内容は特にエラーチェックしない
-		//$contentText = $this->convertToDispString($fetchedRow['cn_html']);
 		$contentText = $fetchedRow['cn_html'];
-		$contentText = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $contentText);// アプリケーションルートを変換
+		$contentText = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $contentText);// アプリケーションルートを変換
 		
 		// 登録したキーワードを変換
 		$this->gInstance->getTextConvManager()->convByKeyValue($contentText, $contentText, true/*改行コーをbrタグに変換*/);
 		
+		// 携帯用コンテンツに変換
+		$contentText = $this->gInstance->getTextConvManager()->autoConvPcContentToMobile($contentText, $this->currentRootUrl/*現在のページのルートURL*/, 
+																				M3_VIEW_TYPE_CONTENT/*汎用コンテンツ*/, $fetchedRow['cn_create_dt']/*コンテンツ作成日時*/);
+		
 		$row = array(
 			'title' => $title,
 			'content' => $contentText	// コンテンツ
