@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: plugin.php 1108 2008-10-23 11:46:32Z fishbone $
+ * @version    SVN: $Id: plugin.php 3474 2010-08-13 10:36:48Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -140,7 +140,7 @@ function do_plugin_convert($name, $args = '')
 		$aryargs = csv_explode(',', $args); // #plugin(A,B,C,D)
 	}
 	if (! PKWKEXP_DISABLE_MULTILINE_PLUGIN_HACK) {
-		if (isset($body)) $aryargs[] = & $body;     // #plugin(){{body}}
+		if (isset($body)) $aryargs[] = $body;     // #plugin(){{body}}
 	}
 
 	$_digest = $digest;
@@ -175,7 +175,7 @@ function do_plugin_inline($name, $args, & $body)
 	}
 
 	// NOTE: A reference of $body is always the last argument
-	$aryargs[] = & $body; // func_num_args() != 0
+	$aryargs[] = $body; // func_num_args() != 0
 
 	$_digest = $digest;
 	$retvar  = call_user_func_array('plugin_' . $name . '_inline', $aryargs);
